function [D,H] = readsegy(filename,hw,min,max,hasb)
%READSEGY  READSEGY(filename,hw,mi,max,hasb) returns the data D and
%          the trace header H. The data and headers are extracted 
%          in the  range of the hw given by min and max.
%
%   example:    [D,H] = readsegy('data','cdp',500,550) will provide
%               the traces and associated headers for traces with the 
%               header word cdp goes from 500 to 550.
%
%   example:    [D,H] = readsegy('data','offset',250,510) like the above
%               example but now the header word 'offset' is used to
%               read traces with offsets in the range 250-500mts.
%
%   example:    [D,H] = readsegy('data') reads everything until end
%               of file.
%
%  M.D.Sacchi, July 1997, Dept. of Physics, UofA.
%        
%  sacchi@phys.ualberta.ca
%
% KS 25.5.98: Argument hasb was added. If hasb==1 then Header is returned
%             as bytes. (240 bytes). If hasb is not given or hasb~=1
%             then function works as before, and header is returned as
%             a structure.
%  

	if (exist('hasb')~=1); hasb=0; end;
 
%   FID = fopen(filename,'r','b');   % when running on a Linux based PC

	FID = fopen(filename,'r');        % when running on a SUN system
                                     % or Windows PC
   
   load segy.mat                     % load the definitions of 
                                     % the header words

   load count.mat                    % load the position of 
                                     % each word in the header (in bytes)

   status = fseek(FID,count.ns,'bof'); % go to the begining of file

   ns = fread(FID,1,segy.ns);        % read ns from first trace
                                     % ns is the number of samples per trace

   total = 60+ns;                    % total nuber of 4bytes words


   max_traces=9999999;               % maximum number of traces (will
                                     % stop before). The variable status
                                     % will make the code stop when
                                     % the end of file is reached  

if (nargin > 1)
   hc=eval(strcat('count.',hw));     % assigned the header word required  
   hp=eval(strcat('segy.',hw));      % to extract the traces.
   j = 1;                            % counter 
   for k =1:max_traces
      position = total*(k-1)*4+hc;   % where in bytes is the header word
      status = fseek(FID,position,'bof'); 
      if status == 0                 % stop when end of file is reached
         w = fread(FID,1,hp);
         if  w>=min                  % pick traces with a given range
            if w<=max                % of the desired header word
               position = total*(k-1)*4+count.trace;
               status = fseek(FID,position,'bof'); 
               trace = fread(FID,ns,segy.trace);
               D(:,j)  = trace(:);   % load traces into D
               if (hasb==1)
                  position = total*(k-1)*4;
                  status = fseek(FID,position,'bof'); 
                  H(:,j)= fread(FID,count.trace,'uint8');
               else              % load each header in a structure H
                  H(j)  = header(FID,ns,k);           
               end
               disp(j)
               j = j + 1;  
            end
         end
      else
			fclose(FID);
         return
      end
   end 
else   % nargin == 1, when no hw and bounds are given, reads everything
   for k =1:max_traces
      position = total*(k-1)*4+count.trace;
      status = fseek(FID,position,'bof'); 
      if status == 0                 
         trace = fread(FID,ns,segy.trace);
         D(:,k)  = trace(:);           % load traces into D
         if (hasb==1)
            position = total*(k-1)*4;
            status = fseek(FID,position,'bof'); 
            H(:,j)= fread(FID,count.trace,'uint8');
         else
            H(k)  = header(FID,ns,k); % load each header in a structure H
         end
         disp(k)
      else
			fclose(FID);
         return
      end
   end 
end 

[message,errnum] = ferror(FID)
fclose(FID);


   

